# coding: utf-8

"""
    Kubeflow Spark Operator OpenAPI Spec

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: unversioned
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from kubeflow_spark_api.models.io_k8s_apimachinery_pkg_apis_meta_v1_condition import IoK8sApimachineryPkgApisMetaV1Condition
from kubeflow_spark_api.models.spark_v1alpha1_spark_connect_server_status import SparkV1alpha1SparkConnectServerStatus
from typing import Optional, Set
from typing_extensions import Self

class SparkV1alpha1SparkConnectStatus(BaseModel):
    """
    SparkConnectStatus defines the observed state of SparkConnect.
    """ # noqa: E501
    conditions: Optional[List[IoK8sApimachineryPkgApisMetaV1Condition]] = Field(default=None, description="Represents the latest available observations of a SparkConnect's current state.")
    executors: Optional[Dict[str, StrictInt]] = Field(default=None, description="Executors represents the current state of the SparkConnect executors.")
    last_update_time: Optional[datetime] = Field(default=None, description="LastUpdateTime is the time at which the SparkConnect controller last updated the SparkConnect.", alias="lastUpdateTime")
    server: Optional[SparkV1alpha1SparkConnectServerStatus] = Field(default=None, description="Server represents the current state of the SparkConnect server.")
    start_time: Optional[datetime] = Field(default=None, description="StartTime is the time at which the SparkConnect controller started processing the SparkConnect.", alias="startTime")
    state: Optional[StrictStr] = Field(default=None, description="State represents the current state of the SparkConnect.")
    __properties: ClassVar[List[str]] = ["conditions", "executors", "lastUpdateTime", "server", "startTime", "state"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SparkV1alpha1SparkConnectStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item_conditions in self.conditions:
                if _item_conditions:
                    _items.append(_item_conditions.to_dict())
            _dict['conditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of server
        if self.server:
            _dict['server'] = self.server.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SparkV1alpha1SparkConnectStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "conditions": [IoK8sApimachineryPkgApisMetaV1Condition.from_dict(_item) for _item in obj["conditions"]] if obj.get("conditions") is not None else None,
            "executors": obj.get("executors"),
            "lastUpdateTime": obj.get("lastUpdateTime"),
            "server": SparkV1alpha1SparkConnectServerStatus.from_dict(obj["server"]) if obj.get("server") is not None else None,
            "startTime": obj.get("startTime"),
            "state": obj.get("state")
        })
        return _obj


