# coding: utf-8

"""
    Kubeflow Spark Operator OpenAPI Spec

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: unversioned
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SparkV1beta2ScheduledSparkApplicationStatus(BaseModel):
    """
    ScheduledSparkApplicationStatus defines the observed state of ScheduledSparkApplication.
    """ # noqa: E501
    last_run: Optional[datetime] = Field(default=None, description="LastRun is the time when the last run of the application started.", alias="lastRun")
    last_run_name: Optional[StrictStr] = Field(default=None, description="LastRunName is the name of the SparkApplication for the most recent run of the application.", alias="lastRunName")
    next_run: Optional[datetime] = Field(default=None, description="NextRun is the time when the next run of the application will start.", alias="nextRun")
    past_failed_run_names: Optional[List[StrictStr]] = Field(default=None, description="PastFailedRunNames keeps the names of SparkApplications for past failed runs.", alias="pastFailedRunNames")
    past_successful_run_names: Optional[List[StrictStr]] = Field(default=None, description="PastSuccessfulRunNames keeps the names of SparkApplications for past successful runs.", alias="pastSuccessfulRunNames")
    reason: Optional[StrictStr] = Field(default=None, description="Reason tells why the ScheduledSparkApplication is in the particular ScheduleState.")
    schedule_state: Optional[StrictStr] = Field(default=None, description="ScheduleState is the current scheduling state of the application.", alias="scheduleState")
    __properties: ClassVar[List[str]] = ["lastRun", "lastRunName", "nextRun", "pastFailedRunNames", "pastSuccessfulRunNames", "reason", "scheduleState"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SparkV1beta2ScheduledSparkApplicationStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SparkV1beta2ScheduledSparkApplicationStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "lastRun": obj.get("lastRun"),
            "lastRunName": obj.get("lastRunName"),
            "nextRun": obj.get("nextRun"),
            "pastFailedRunNames": obj.get("pastFailedRunNames"),
            "pastSuccessfulRunNames": obj.get("pastSuccessfulRunNames"),
            "reason": obj.get("reason"),
            "scheduleState": obj.get("scheduleState")
        })
        return _obj


