# coding: utf-8

"""
    Kubeflow Spark Operator OpenAPI Spec

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: unversioned
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SparkV1alpha1DynamicAllocation(BaseModel):
    """
    DynamicAllocation contains configuration options for dynamic allocation.
    """ # noqa: E501
    enabled: Optional[StrictBool] = Field(default=None, description="Enabled controls whether dynamic allocation is enabled or not.")
    initial_executors: Optional[StrictInt] = Field(default=None, description="InitialExecutors is the initial number of executors to request. If .spec.executor.instances is also set, the initial number of executors is set to the bigger of that and this option.", alias="initialExecutors")
    max_executors: Optional[StrictInt] = Field(default=None, description="MaxExecutors is the upper bound for the number of executors if dynamic allocation is enabled.", alias="maxExecutors")
    min_executors: Optional[StrictInt] = Field(default=None, description="MinExecutors is the lower bound for the number of executors if dynamic allocation is enabled.", alias="minExecutors")
    shuffle_tracking_enabled: Optional[StrictBool] = Field(default=None, description="ShuffleTrackingEnabled enables shuffle file tracking for executors, which allows dynamic allocation without the need for an external shuffle service. This option will try to keep alive executors that are storing shuffle data for active jobs. If external shuffle service is enabled, set ShuffleTrackingEnabled to false. ShuffleTrackingEnabled is true by default if dynamicAllocation.enabled is true.", alias="shuffleTrackingEnabled")
    shuffle_tracking_timeout: Optional[StrictInt] = Field(default=None, description="ShuffleTrackingTimeout controls the timeout in milliseconds for executors that are holding shuffle data if shuffle tracking is enabled (true by default if dynamic allocation is enabled).", alias="shuffleTrackingTimeout")
    __properties: ClassVar[List[str]] = ["enabled", "initialExecutors", "maxExecutors", "minExecutors", "shuffleTrackingEnabled", "shuffleTrackingTimeout"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SparkV1alpha1DynamicAllocation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SparkV1alpha1DynamicAllocation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "enabled": obj.get("enabled"),
            "initialExecutors": obj.get("initialExecutors"),
            "maxExecutors": obj.get("maxExecutors"),
            "minExecutors": obj.get("minExecutors"),
            "shuffleTrackingEnabled": obj.get("shuffleTrackingEnabled"),
            "shuffleTrackingTimeout": obj.get("shuffleTrackingTimeout")
        })
        return _obj


