# coding: utf-8

"""
    Kubeflow Spark Operator OpenAPI Spec

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: unversioned
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SparkV1beta2Dependencies(BaseModel):
    """
    Dependencies specifies all possible types of dependencies of a Spark application.
    """ # noqa: E501
    archives: Optional[List[StrictStr]] = Field(default=None, description="Archives is a list of archives to be extracted into the working directory of each executor.")
    exclude_packages: Optional[List[StrictStr]] = Field(default=None, description="ExcludePackages is a list of \"groupId:artifactId\", to exclude while resolving the dependencies provided in Packages to avoid dependency conflicts.", alias="excludePackages")
    files: Optional[List[StrictStr]] = Field(default=None, description="Files is a list of files the Spark application depends on.")
    jars: Optional[List[StrictStr]] = Field(default=None, description="Jars is a list of JAR files the Spark application depends on.")
    packages: Optional[List[StrictStr]] = Field(default=None, description="Packages is a list of maven coordinates of jars to include on the driver and executor classpaths. This will search the local maven repo, then maven central and any additional remote repositories given by the \"repositories\" option. Each package should be of the form \"groupId:artifactId:version\".")
    py_files: Optional[List[StrictStr]] = Field(default=None, description="PyFiles is a list of Python files the Spark application depends on.", alias="pyFiles")
    repositories: Optional[List[StrictStr]] = Field(default=None, description="Repositories is a list of additional remote repositories to search for the maven coordinate given with the \"packages\" option.")
    __properties: ClassVar[List[str]] = ["archives", "excludePackages", "files", "jars", "packages", "pyFiles", "repositories"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SparkV1beta2Dependencies from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SparkV1beta2Dependencies from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "archives": obj.get("archives"),
            "excludePackages": obj.get("excludePackages"),
            "files": obj.get("files"),
            "jars": obj.get("jars"),
            "packages": obj.get("packages"),
            "pyFiles": obj.get("pyFiles"),
            "repositories": obj.get("repositories")
        })
        return _obj


